:orphan:



.. _sphx_glr_documentation_auto_examples_ahr:

========================================
Example: Approximate hubness reduction
========================================

These examples show how to combine approximate nearest neighbor search and hubness reduction.



.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to reuse index structures. If you want to first estimate hubness, and th...">

.. only:: html

    .. figure:: /documentation/auto_examples_ahr/images/thumb/sphx_glr_reusing_index_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_ahr_reusing_index.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples_ahr/reusing_index

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to combine approximate nearest neighbor search and hubness reduction in ...">

.. only:: html

    .. figure:: /documentation/auto_examples_ahr/images/thumb/sphx_glr_high_dim_gaussian_thumb.png

        :ref:`sphx_glr_documentation_auto_examples_ahr_high_dim_gaussian.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /documentation/auto_examples_ahr/high_dim_gaussian
.. raw:: html

    <div style='clear:both'></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download

    :download:`Download all examples in Python source code: auto_examples_ahr_python.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples_ahr/auto_examples_ahr_python.zip>`



  .. container:: sphx-glr-download

    :download:`Download all examples in Jupyter notebooks: auto_examples_ahr_jupyter.zip <//home/user/feldbauer/PycharmProjects/hubness/docs/documentation/auto_examples_ahr/auto_examples_ahr_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
